@@ -22,5 +22,6 @@ urlpatterns = [
     url(r'^get_active_loans/', views.GetActiveLoanByAppIds.as_view(), name='get-active-loan'),
     url(r'^get_data_custconadd/', views.GetDataCustConAdd.as_view(), name='get-data-custconadd'), #nguyenhuuvinh4
     url(r'^get_blacklisted_accounts/', views.GetBlacklistedAccounts.as_view(), name='get_blacklisted_accounts'),
-    url(r'^get_aml_data/', views.getAMLTableData.as_view(), name='get_aml_data')
+    url(r'^get_aml_data/', views.getAMLTableData.as_view(), name='get_aml_data'),
+    url(r'^get_data_dwh/', views.GetRegisAndActHiFromDWHRequestSerializer.as_view(), name='get_data_dwh'),
 ]
\ No newline at end of file
