@@ -883,6 +883,22 @@ class GetDataCustConAdd(GenericSoapAPIView):
         return base_app_utils.response(rq_srl.errors, status.HTTP_400_BAD_REQUEST, error="error")
 #nguyenhuuvinh4 END
 
+class GetRegisAndActHiFromDWHRequestSerializer(APIView):
+    print("tests GetRegisAndActHiFromDWHRequestSerializer")
+    def post(self, request):
+        rq_srl = fec_dbsync_serializers.GetRegisAndActHiFromDWHRequestSerializer(
+            data=request.data)
+        if rq_srl.is_valid():
+            try:
+                response = Utils.get_registration_and_act_hi_var_from_dwh(
+                    rq_srl.data.get('appId'))
+                return base_app_utils.response(response, status.HTTP_200_OK)
+            except Exception as e:
+                print(e)
+                return base_app_utils.response({"message": "Something went wrong"},
+                                               status.HTTP_500_INTERNAL_SERVER_ERROR, error="error")
+        return base_app_utils.response(rq_srl.errors, status.HTTP_400_BAD_REQUEST, error="error")
+
 class GetActiveLoanByAppIds(APIView):
     def post(self, request):
         rq_srl = fec_dbsync_serializers.GetActiveLoanByAppIdsRequestSerializer(data=request.data)
